@@ -1,4 +1,4 @@
-package URI::Query::FromHash 0.003;
+package URI::Query::FromHash 0.004;
 
 use strict;
 use warnings;
@@ -13,9 +13,13 @@ sub import {
 }
 
 sub hash2query(+%) {
+    return '' if 'HASH' ne ref( my $hash = $_[0] );
+
     my $q = '';
 
-    while ( my ($k, $v) = each %{ $_[0] // return '' } ) {
+    for my $k ( sort keys %$hash ) {
+        my $v = $hash->{$k};
+
         $k =~ s|([;/?:@&=+,\$\[\]%])|$escapes{$1}|g;
         $k =~ y| |+|;
 
